@@ -1,6 +1,6 @@
 use std::path::PathBuf;
 
-use img_hash::{FilterType, HashAlg};
+use image_hasher::{FilterType, HashAlg};
 use structopt::StructOpt;
 
 use czkawka_core::common_dir_traversal::CheckingMethod;
@@ -37,6 +37,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
         #[structopt(flatten)]
         allow_hard_links: AllowHardLinks,
         #[structopt(flatten)]
@@ -54,6 +57,9 @@ pub enum Commands {
         delete_folders: bool,
         #[structopt(flatten)]
         file_to_save: FileToSave,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "big", about = "Finds big files", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka big -d /home/rafal/ /home/piszczal -e /home/rafal/Roman -n 25 -x VIDEO -f results.txt")]
     BiggestFiles {
@@ -73,6 +79,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "empty-files", about = "Finds empty files", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka empty-files -d /home/rafal /home/szczekacz -e /home/rafal/Pulpit -R -f results.txt")]
     EmptyFiles {
@@ -90,6 +99,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "temp", about = "Finds temporary files", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka temp -d /home/rafal/ -E */.git */tmp* *Pulpit -f results.txt -D")]
     Temporary {
@@ -105,6 +117,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "image", about = "Finds similar images", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka image -d /home/rafal/ -E */.git */tmp* *Pulpit -f results.txt")]
     SimilarImages {
@@ -124,6 +139,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
         #[structopt(short = "g", long, default_value = "Gradient", parse(try_from_str = parse_similar_hash_algorithm), help = "Hash algorithm (allowed: Mean, Gradient, Blockhash, VertGradient, DoubleGradient)")]
         hash_alg: HashAlg,
         #[structopt(short = "z", long, default_value = "Lanczos3", parse(try_from_str = parse_similar_image_filter), help = "Hash algorithm (allowed: Lanczos3, Nearest, Triangle, Faussian, Catmullrom)")]
@@ -141,12 +159,15 @@ pub enum Commands {
         excluded_items: ExcludedItems,
         // #[structopt(short = "D", long, help = "Delete found files")]
         // delete_files: bool, TODO
-        #[structopt(short = "z", long, default_value = "artist,title", parse(try_from_str = parse_music_duplicate_type), help = "Search method (title, artist, album_title, album_artist, year)", long_help = "Sets which rows must be equal to set this files as duplicates(may be mixed, but must be divided by commas).")]
+        #[structopt(short = "z", long, default_value = "track_title,track_artist", parse(try_from_str = parse_music_duplicate_type), help = "Search method (track_title,track_artist,year,bitrate,genre,length))", long_help = "Sets which rows must be equal to set this files as duplicates(may be mixed, but must be divided by commas).")]
         music_similarity: MusicSimilarity,
         #[structopt(flatten)]
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
         #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "8192", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
         #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
@@ -168,6 +189,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "broken", about = "Finds broken files", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka broken -d /home/kicikici/ /home/szczek -e /home/kicikici/jestempsem -x jpg -f results.txt")]
     BrokenFiles {
@@ -185,6 +209,9 @@ pub enum Commands {
         file_to_save: FileToSave,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
     },
     #[structopt(name = "video", about = "Finds similar video files", help_message = HELP_MESSAGE, after_help = "EXAMPLE:\n    czkawka videos -d /home/rafal -f results.txt")]
     SimilarVideos {
@@ -202,6 +229,9 @@ pub enum Commands {
         allowed_extensions: AllowedExtensions,
         #[structopt(flatten)]
         not_recursive: NotRecursive,
+        #[cfg(target_family = "unix")]
+        #[structopt(flatten)]
+        exclude_other_filesystems: ExcludeOtherFilesystems,
         #[structopt(short, long, parse(try_from_str = parse_minimal_file_size), default_value = "8192", help = "Minimum size in bytes", long_help = "Minimum size of checked files in bytes, assigning bigger value may speed up searching")]
         minimal_file_size: u64,
         #[structopt(short = "i", long, parse(try_from_str = parse_maximal_file_size), default_value = "18446744073709551615", help = "Maximum size in bytes", long_help = "Maximum size of checked files in bytes, assigning lower value may speed up searching")]
@@ -269,6 +299,13 @@ pub struct NotRecursive {
     pub not_recursive: bool,
 }
 
+#[cfg(target_family = "unix")]
+#[derive(Debug, StructOpt)]
+pub struct ExcludeOtherFilesystems {
+    #[structopt(short = "X", long, help = "Exclude files on other filesystmes")]
+    pub exclude_other_filesystems: bool,
+}
+
 #[derive(Debug, StructOpt)]
 pub struct FileToSave {
     #[structopt(short, long, value_name = "file-name", help = "Saves the results into the file")]
@@ -414,26 +451,29 @@ fn parse_music_duplicate_type(src: &str) -> Result<MusicSimilarity, String> {
 
     let mut similarity: MusicSimilarity = MusicSimilarity::NONE;
 
-    let parts: Vec<&str> = src.split(',').collect();
+    let parts: Vec<String> = src.split(',').map(|e| e.to_lowercase().replace('_', "")).collect();
 
-    if parts.iter().any(|e| e.to_lowercase().contains("title") && !e.to_lowercase().contains("album")) {
-        similarity |= MusicSimilarity::TITLE;
+    if parts.iter().any(|e| e.contains("tracktitle")) {
+        similarity |= MusicSimilarity::TRACK_TITLE;
     }
-    if parts.iter().any(|e| e.to_lowercase().contains("artist") && !e.to_lowercase().contains("album")) {
-        similarity |= MusicSimilarity::ARTIST;
+    if parts.iter().any(|e| e.contains("trackartist")) {
+        similarity |= MusicSimilarity::TRACK_ARTIST;
     }
-    if parts.iter().any(|e| e.to_lowercase().contains("title") && e.to_lowercase().contains("album")) {
-        similarity |= MusicSimilarity::ALBUM_TITLE;
-    }
-    if parts.iter().any(|e| e.to_lowercase().contains("artist") && e.to_lowercase().contains("album")) {
-        similarity |= MusicSimilarity::ALBUM_ARTIST;
-    }
-    if parts.iter().any(|e| e.to_lowercase().contains("year")) {
+    if parts.iter().any(|e| e.contains("year")) {
         similarity |= MusicSimilarity::YEAR;
     }
+    if parts.iter().any(|e| e.contains("bitrate")) {
+        similarity |= MusicSimilarity::BITRATE;
+    }
+    if parts.iter().any(|e| e.contains("genre")) {
+        similarity |= MusicSimilarity::GENRE;
+    }
+    if parts.iter().any(|e| e.contains("length")) {
+        similarity |= MusicSimilarity::LENGTH;
+    }
 
     if similarity == MusicSimilarity::NONE {
-        return Err("Couldn't parse the music search method (allowed: title,artist,album_title,album_artist,year)".to_string());
+        return Err("Couldn't parse the music search method (allowed: track_title,track_artist,year,bitrate,genre,length)".to_string());
     }
 
     Ok(similarity)
