@@ -1,3 +1,5 @@
+#![allow(clippy::needless_late_init)]
+
 use std::process;
 
 use structopt::StructOpt;
@@ -42,6 +44,8 @@ fn main() {
             hash_type,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             allow_hard_links,
             dryrun,
         } => {
@@ -58,6 +62,8 @@ fn main() {
             df.set_delete_method(delete_method);
             df.set_hash_type(hash_type);
             df.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            df.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             df.set_ignore_hard_links(!allow_hard_links.allow_hard_links);
             df.set_dryrun(dryrun.dryrun);
 
@@ -80,6 +86,8 @@ fn main() {
             file_to_save,
             excluded_directories,
             excluded_items,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
         } => {
             let mut ef = EmptyFolder::new();
 
@@ -87,6 +95,8 @@ fn main() {
             ef.set_excluded_directory(excluded_directories.excluded_directories);
             ef.set_excluded_items(excluded_items.excluded_items);
             ef.set_delete_folder(delete_folders);
+            #[cfg(target_family = "unix")]
+            ef.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
 
             ef.find_empty_folders(None, None);
 
@@ -109,6 +119,8 @@ fn main() {
             number_of_files,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             delete_files,
         } => {
             let mut bf = BigFile::new();
@@ -119,6 +131,8 @@ fn main() {
             bf.set_allowed_extensions(allowed_extensions.allowed_extensions.join(","));
             bf.set_number_of_files_to_check(number_of_files);
             bf.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            bf.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             if delete_files {
                 bf.set_delete_method(big_file::DeleteMethod::Delete);
             }
@@ -144,6 +158,8 @@ fn main() {
             delete_files,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
         } => {
             let mut ef = EmptyFiles::new();
 
@@ -152,6 +168,8 @@ fn main() {
             ef.set_excluded_items(excluded_items.excluded_items);
             ef.set_allowed_extensions(allowed_extensions.allowed_extensions.join(","));
             ef.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            ef.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
 
             if delete_files {
                 ef.set_delete_method(empty_files::DeleteMethod::Delete);
@@ -174,6 +192,8 @@ fn main() {
             directories,
             excluded_directories,
             excluded_items,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             delete_files,
             file_to_save,
             not_recursive,
@@ -184,6 +204,8 @@ fn main() {
             tf.set_excluded_directory(excluded_directories.excluded_directories);
             tf.set_excluded_items(excluded_items.excluded_items);
             tf.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            tf.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
 
             if delete_files {
                 tf.set_delete_method(temporary::DeleteMethod::Delete);
@@ -211,6 +233,8 @@ fn main() {
             maximal_file_size,
             similarity_preset,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             hash_alg,
             image_filter,
             hash_size,
@@ -223,6 +247,8 @@ fn main() {
             sf.set_minimal_file_size(minimal_file_size);
             sf.set_maximal_file_size(maximal_file_size);
             sf.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            sf.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             sf.set_image_filter(image_filter);
             sf.set_hash_alg(hash_alg);
             sf.set_hash_size(hash_size);
@@ -249,6 +275,8 @@ fn main() {
             // delete_files,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             minimal_file_size,
             maximal_file_size,
             music_similarity,
@@ -261,6 +289,8 @@ fn main() {
             mf.set_minimal_file_size(minimal_file_size);
             mf.set_maximal_file_size(maximal_file_size);
             mf.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            mf.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             mf.set_music_similarity(music_similarity);
 
             // if delete_files {
@@ -287,6 +317,8 @@ fn main() {
             allowed_extensions,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             delete_files,
         } => {
             let mut ifs = InvalidSymlinks::new();
@@ -296,6 +328,8 @@ fn main() {
             ifs.set_excluded_items(excluded_items.excluded_items);
             ifs.set_allowed_extensions(allowed_extensions.allowed_extensions.join(","));
             ifs.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            ifs.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             if delete_files {
                 ifs.set_delete_method(invalid_symlinks::DeleteMethod::Delete);
             }
@@ -321,6 +355,8 @@ fn main() {
             delete_files,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
         } => {
             let mut br = BrokenFiles::new();
 
@@ -329,6 +365,8 @@ fn main() {
             br.set_excluded_items(excluded_items.excluded_items);
             br.set_allowed_extensions(allowed_extensions.allowed_extensions.join(","));
             br.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            br.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
 
             if delete_files {
                 br.set_delete_method(broken_files::DeleteMethod::Delete);
@@ -353,6 +391,8 @@ fn main() {
             excluded_items,
             file_to_save,
             not_recursive,
+            #[cfg(target_family = "unix")]
+            exclude_other_filesystems,
             tolerance,
             minimal_file_size,
             maximal_file_size,
@@ -365,6 +405,8 @@ fn main() {
             vr.set_excluded_items(excluded_items.excluded_items);
             vr.set_allowed_extensions(allowed_extensions.allowed_extensions.join(","));
             vr.set_recursive_search(!not_recursive.not_recursive);
+            #[cfg(target_family = "unix")]
+            vr.set_exclude_other_filesystems(exclude_other_filesystems.exclude_other_filesystems);
             vr.set_minimal_file_size(minimal_file_size);
             vr.set_maximal_file_size(maximal_file_size);
             vr.set_tolerance(tolerance);
